@@ -3,6 +3,7 @@
 
 import collections
 import logging
+import warnings
 
 from . import builder, declarations, enums, errors, utils
 
@@ -90,7 +91,7 @@ class FactoryMetaClass(type):
         if cls._meta.abstract:
             return '<%s (abstract)>' % cls.__name__
         else:
-            return '<%s for %s>' % (cls.__name__, cls._meta.model)
+            return f'<{cls.__name__} for {cls._meta.model}>'
 
 
 class BaseMeta:
@@ -506,12 +507,12 @@ class BaseFactory:
 
     @classmethod
     def build(cls, **kwargs):
-        """Build an instance of the associated class, with overriden attrs."""
+        """Build an instance of the associated class, with overridden attrs."""
         return cls._generate(enums.BUILD_STRATEGY, kwargs)
 
     @classmethod
     def build_batch(cls, size, **kwargs):
-        """Build a batch of instances of the given class, with overriden attrs.
+        """Build a batch of instances of the given class, with overridden attrs.
 
         Args:
             size (int): the number of instances to build
@@ -523,12 +524,12 @@ class BaseFactory:
 
     @classmethod
     def create(cls, **kwargs):
-        """Create an instance of the associated class, with overriden attrs."""
+        """Create an instance of the associated class, with overridden attrs."""
         return cls._generate(enums.CREATE_STRATEGY, kwargs)
 
     @classmethod
     def create_batch(cls, size, **kwargs):
-        """Create a batch of instances of the given class, with overriden attrs.
+        """Create a batch of instances of the given class, with overridden attrs.
 
         Args:
             size (int): the number of instances to create
@@ -540,7 +541,7 @@ class BaseFactory:
 
     @classmethod
     def stub(cls, **kwargs):
-        """Retrieve a stub of the associated class, with overriden attrs.
+        """Retrieve a stub of the associated class, with overridden attrs.
 
         This will return an object whose attributes are those defined in this
         factory's declarations or in the extra kwargs.
@@ -549,7 +550,7 @@ class BaseFactory:
 
     @classmethod
     def stub_batch(cls, size, **kwargs):
-        """Stub a batch of instances of the given class, with overriden attrs.
+        """Stub a batch of instances of the given class, with overridden attrs.
 
         Args:
             size (int): the number of instances to stub
@@ -696,10 +697,9 @@ class BaseListFactory(Factory):
             raise ValueError(
                 "ListFactory %r does not support Meta.inline_args." % cls)
 
-        # When support for Python <3.6 is dropped sorting will no longer be required
-        # because dictionaries will already be ordered, this can then be changed to:
-        # values = kwargs.values()
-        values = [v for k, v in sorted(kwargs.items(), key=lambda item: int(item[0]))]
+        # kwargs are constructed from a list, their insertion order matches the list
+        # order, no additional sorting is required.
+        values = kwargs.values()
         return model_class(values)
 
     @classmethod
@@ -717,6 +717,12 @@ def use_strategy(new_strategy):
 
     This is an alternative to setting default_strategy in the class definition.
     """
+    warnings.warn(
+        "use_strategy() is deprecated and will be removed in the future.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
     def wrapped_class(klass):
         klass._meta.strategy = new_strategy
         return klass
